@@ -287,73 +287,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CONF_OPERATOR );
         r( wxSTC_CONF_IP );
         r( wxSTC_CONF_DIRECTIVE );
-        r( wxSTC_CMD_REDO );
-        r( wxSTC_CMD_SELECTALL );
-        r( wxSTC_CMD_UNDO );
-        r( wxSTC_CMD_CUT );
-        r( wxSTC_CMD_COPY );
-        r( wxSTC_CMD_PASTE );
-        r( wxSTC_CMD_LINEDOWN );
-        r( wxSTC_CMD_LINEDOWNEXTEND );
-        r( wxSTC_CMD_LINEUP );
-        r( wxSTC_CMD_LINEUPEXTEND );
-        r( wxSTC_CMD_LINECOPY );
-        r( wxSTC_CMD_CHARLEFT );
-        r( wxSTC_CMD_CHARLEFTEXTEND );
-        r( wxSTC_CMD_CHARRIGHT );
-        r( wxSTC_CMD_CHARRIGHTEXTEND );
-        r( wxSTC_CMD_WORDLEFT );
-        r( wxSTC_CMD_WORDLEFTEXTEND );
-        r( wxSTC_CMD_WORDRIGHT );
-        r( wxSTC_CMD_WORDRIGHTEXTEND );
-        r( wxSTC_CMD_HOME );
-        r( wxSTC_CMD_HOMEEXTEND );
-        r( wxSTC_CMD_LINEEND );
-        r( wxSTC_CMD_LINEENDEXTEND );
-        r( wxSTC_CMD_DOCUMENTSTART );
-        r( wxSTC_CMD_DOCUMENTSTARTEXTEND );
-        r( wxSTC_CMD_DOCUMENTEND );
-        r( wxSTC_CMD_DOCUMENTENDEXTEND );
-        r( wxSTC_CMD_PAGEUP );
-        r( wxSTC_CMD_PAGEUPEXTEND );
-        r( wxSTC_CMD_PAGEDOWN );
-        r( wxSTC_CMD_PAGEDOWNEXTEND );
-        r( wxSTC_CMD_PARADOWN );
-        r( wxSTC_CMD_PARADOWNEXTEND );
-        r( wxSTC_CMD_PARAUP );
-        r( wxSTC_CMD_PARAUPEXTEND );
-        r( wxSTC_CMD_EDITTOGGLEOVERTYPE );
-        r( wxSTC_CMD_CANCEL );
-        r( wxSTC_CMD_DELETEBACK );
-        r( wxSTC_CMD_TAB );
-        r( wxSTC_CMD_BACKTAB );
-        r( wxSTC_CMD_NEWLINE );
-        r( wxSTC_CMD_FORMFEED );
-        r( wxSTC_CMD_VCHOME );
-        r( wxSTC_CMD_VCHOMEEXTEND );
-        r( wxSTC_CMD_ZOOMIN );
-        r( wxSTC_CMD_ZOOMOUT );
-        r( wxSTC_CMD_DELWORDLEFT );
-        r( wxSTC_CMD_DELWORDRIGHT );
-        r( wxSTC_CMD_LINECUT );
-        r( wxSTC_CMD_LINEDELETE );
-        r( wxSTC_CMD_LINETRANSPOSE );
-        r( wxSTC_CMD_LOWERCASE );
-        r( wxSTC_CMD_UPPERCASE );
-        r( wxSTC_CMD_LINESCROLLDOWN );
-        r( wxSTC_CMD_LINESCROLLUP );
-        r( wxSTC_CMD_DELETEBACKNOTLINE );
-        r( wxSTC_CMD_HOMEDISPLAY );
-        r( wxSTC_CMD_HOMEDISPLAYEXTEND );
-        r( wxSTC_CMD_LINEENDDISPLAY );
-        r( wxSTC_CMD_LINEENDDISPLAYEXTEND );
-        r( wxSTC_CMD_CLEAR );
-        r( wxSTC_CMD_WORDPARTLEFT );
-        r( wxSTC_CMD_WORDPARTLEFTEXTEND );
-        r( wxSTC_CMD_WORDPARTRIGHT );
-        r( wxSTC_CMD_WORDPARTRIGHTEXTEND );
-        r( wxSTC_CMD_DELLINELEFT );
-        r( wxSTC_CMD_DELLINERIGHT );
         r( wxSTC_CSS_DEFAULT );
         r( wxSTC_CSS_TAG );
         r( wxSTC_CSS_CLASS );
@@ -418,31 +351,6 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CMAKE_USERDEFINED );
         r( wxSTC_CMAKE_VARIABLE );
         r( wxSTC_CMAKE_WHILEDEF );
-        r( wxSTC_CMD_CHARLEFTRECTEXTEND );
-        r( wxSTC_CMD_CHARRIGHTRECTEXTEND );
-        r( wxSTC_CMD_DELWORDRIGHTEND );
-        r( wxSTC_CMD_HOMERECTEXTEND );
-        r( wxSTC_CMD_HOMEWRAP );
-        r( wxSTC_CMD_HOMEWRAPEXTEND );
-        r( wxSTC_CMD_LINEDOWNRECTEXTEND );
-        r( wxSTC_CMD_LINEDUPLICATE );
-        r( wxSTC_CMD_LINEENDRECTEXTEND );
-        r( wxSTC_CMD_LINEENDWRAP );
-        r( wxSTC_CMD_LINEENDWRAPEXTEND );
-        r( wxSTC_CMD_LINEUPRECTEXTEND );
-        r( wxSTC_CMD_PAGEDOWNRECTEXTEND );
-        r( wxSTC_CMD_PAGEUPRECTEXTEND );
-        r( wxSTC_CMD_STUTTEREDPAGEDOWN );
-        r( wxSTC_CMD_STUTTEREDPAGEDOWNEXTEND );
-        r( wxSTC_CMD_STUTTEREDPAGEUP );
-        r( wxSTC_CMD_STUTTEREDPAGEUPEXTEND );
-        r( wxSTC_CMD_VCHOMERECTEXTEND );
-        r( wxSTC_CMD_VCHOMEWRAP );
-        r( wxSTC_CMD_VCHOMEWRAPEXTEND );
-        r( wxSTC_CMD_WORDLEFTEND );
-        r( wxSTC_CMD_WORDLEFTENDEXTEND );
-        r( wxSTC_CMD_WORDRIGHTEND );
-        r( wxSTC_CMD_WORDRIGHTENDEXTEND );
         r( wxSTC_CP_DBCS );
         r( wxSTC_CP_UTF8 );
         r( wxSTC_CSOUND_ARATE_VAR );
